[![Aarhus Stadsarkiv](https://raw.githubusercontent.com/aarhusstadsarkiv/py-template/master/img/logo.png)](https://stadsarkiv.aarhus.dk/)
# Digital Archive [![CircleCI](https://circleci.com/gh/aarhusstadsarkiv/digiarch/tree/master.svg?style=shield)](https://circleci.com/gh/aarhusstadsarkiv/digiarch/tree/master) [![codecov](https://codecov.io/gh/aarhusstadsarkiv/digiarch/branch/master/graph/badge.svg)](https://codecov.io/gh/aarhusstadsarkiv/digiarch)
This repository contains code pertaining to the Digital Archive Project at Aarhus Stadsarkiv.
